==> reflext.core-1.0.0-beta3-sources.jar: org/reflext/core/ArrayTypeInfoImpl.java <==
/*
 * Copyright (C) 2003-2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.reflext.core;

import org.reflext.api.ArrayTypeInfo;
import org.reflext.api.TypeInfo;
import org.reflext.api.ClassTypeInfo;

/**
 * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
 * @version $Revision$
 */
public class ArrayTypeInfoImpl<T, M> extends TypeInfoImpl<T, M> implements ArrayTypeInfo {

  /** . */
  private final T type;

  /** . */
  private TypeInfo componentType;


  public ArrayTypeInfoImpl(TypeDomain<T, M> domain, T type) {
    super(domain);

    //
    this.type = type;
  }

  public Object getType() {
    return type;
  }

  public TypeInfo getComponentType() {
    if (componentType == null) {
      T componentType = domain.typeModel.getComponentType(type);
      this.componentType = domain._getType(componentType);
    }
    return componentType;
  }

  public int hashCode() {
    return 1 + getComponentType().hashCode();
  }

  public boolean equals(Object obj) {
    if (obj == this) {
      return true;
    }
    if (obj instanceof ArrayTypeInfo) {
      ArrayTypeInfo that = (ArrayTypeInfo)obj;
      return getComponentType().equals(that.getComponentType());
    }
    return false;
  }
}

==> reflext.core-1.1.0-beta3-sources.jar: org/reflext/core/ArrayTypeInfoImpl.java <==
/*
 * Copyright (C) 2003-2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.reflext.core;

import org.reflext.api.ArrayTypeInfo;
import org.reflext.api.TypeInfo;

/**
 * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
 * @version $Revision$
 */
public class ArrayTypeInfoImpl<T, M, A, P> extends AbstractArrayTypeInfo<T, M, A, P> implements ArrayTypeInfo {

  /** . */
  private final T type;

  /** . */
  private TypeInfo componentType;


  public ArrayTypeInfoImpl(TypeResolverImpl<T, M, A, P> domain, T type) {
    super(domain);

    //
    this.type = type;
  }

  public Object getType() {
    return type;
  }

  public TypeInfo getComponentType() {
    if (componentType == null) {
      T componentType = domain.typeModel.getComponentType(type);
      this.componentType = domain._getType(componentType);
    }
    return componentType;
  }
}
